@@ -6,10 +6,9 @@ from smartroute import RoutedClass, Router, route
 
 
 class LoggedService(RoutedClass):
-    routes = Router(name="logged").plug("logging")
-
     def __init__(self):
         self.calls = 0
+        self.routes = Router(self, name="routes").plug("logging")
 
     @route("routes")
     def hello(self):
@@ -34,7 +33,7 @@ def test_logging_plugin_runs_per_instance(monkeypatch):
             records.append(message)
 
     svc = LoggedService()
-    svc.routes.logger._logger = DummyLogger()  # type: ignore[attr-defined]
+    svc.routes.logging._logger = DummyLogger()  # type: ignore[attr-defined]
 
     assert svc.routes.get("hello")() == "ok"
     assert svc.calls == 1
